@@ -1,6 +1,5 @@
 ﻿#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 import os
 import sys
 from glob import glob
@@ -9,6 +8,17 @@ from psutil import Process
 from datetime import datetime
 if sys.version_info[:2] >= (3, 7):
     from datetime import timezone, timedelta
+PY2 = sys.version_info[0] == 2
+
+# github action problem in windows default codepage 1252 environment
+# https://stackoverflow.com/questions/27092833/unicodeencodeerror-charmap-codec-cant-encode-characters
+defaultencoding = 'utf-8'
+if sys.stdout.encoding != defaultencoding:
+    if PY2:
+        reload(sys)
+        sys.setdefaultencoding(defaultencoding)
+    elif os.name == "nt":
+        sys.stdout.reconfigure(encoding=defaultencoding)
 
 from os.path import dirname, abspath, join as pjoin
 shome = abspath(pjoin(dirname(__file__), ".."))
@@ -19,14 +29,14 @@ sys.path.insert(0, pjoin(shome, "build", "cmake-install"))
 sys.path.insert(0, pjoin(shome, "_skbuild", "cmake-install"))
 try:
     from ccore import *
-    SETUP = "from ccore import *"
+    kw = {"setup": "from ccore import *"} if PY2 else {}
 except ImportError:
     try:
         from _ccore import *
-        SETUP = "from _ccore import *"
+        kw = {"setup": "from _ccore import *"} if PY2 else {}
     except ImportError:
         from ccore._ccore import *
-        SETUP = "from ccore._ccore import *"
+        kw = {"setup": "from ccore._ccore import *"} if PY2 else {}
 
 
 from socket import gethostname
@@ -45,15 +55,13 @@ def memusage():
 
 def runtimeit(funcstr, number=10000):
     i = 0
-    kw = {"number": number}
+    kw["number"] = number
     if sys.version_info[0] >= 3:
         kw["globals"] = globals()
-    else:
-        kw["setup"] = SETUP
 
     for fc in funcstr.strip().splitlines():
         fc = fc.strip()
-        
+
         if i == 0:
             timeit(fc, **kw)
         bm = memusage()
@@ -61,10 +69,7 @@ def runtimeit(funcstr, number=10000):
 
         am = (memusage() - bm)
         assert am < 10000, "{} function {}KB Memory Leak Error".format(fc, am)
-        try:
-            print("{}: {} ns (mem after {}KB)".format(fc, int(1000000000 * p / number), am))
-        except UnicodeEncodeError:
-            print("<UnicodeError text>: {} ns (mem after {}KB)".format(int(1000000000 * p / number), am))
+        print("{}: {} ns (mem after {}KB)".format(fc, int(1000000000 * p / number), am))
         i += 1
 
 
@@ -103,7 +108,7 @@ def test_lookuptype():
     runtimeit("lookuptype(b'PK\\x03\\x04dsfal\\x00')")
 
 def test_guesstype():
-    for g in glob(tdir+"*"):
+    for g in glob(tdir + "*"):
         basename = os.path.basename(g)
         with open(g, "rb") as f:
             print(basename, lookuptype(f.read(256)))
@@ -306,6 +311,7 @@ def test_error_datetime():
     assert(to_datetime("hoge") == None)
     assert(to_datetime(u"ho123年ge") == None)
 
+
 if __name__ == '__main__':
     import os
     import traceback
